@@ -1,4 +1,3 @@
-# TODO: create classes
 # TODO: align clean_xl_data and prepare_xl_data (should work on same dimensions of data)
 
 import os
@@ -7,6 +6,8 @@ from appscript import app
 from appscript import k as kw
 import psutil
 import atexit
+from .constants import ColorIndex
+from .utils import rgb_to_int, int_to_rgb
 try:
     import pandas as pd
 except ImportError:
@@ -328,4 +329,30 @@ def add_sheet(xl_workbook, before, after):
 
 
 def count_worksheets(xl_workbook):
-    return xl_workbook.count(each=kw.worksheet)
\ No newline at end of file
+    return xl_workbook.count(each=kw.worksheet)
+
+
+def get_hyperlink_address(xl_range):
+    return xl_range.hyperlinks[1].address.get()
+
+
+def set_hyperlink(xl_range, address, text_to_display=None, screen_tip=None):
+    xl_range.make(at=xl_range, new=kw.hyperlink, with_properties={kw.address: address,
+                                                                  kw.text_to_display: text_to_display,
+                                                                  kw.screen_tip: screen_tip})
+
+
+def set_color(xl_range, color_or_rgb):
+    if color_or_rgb is None:
+        xl_range.interior_object.color_index.set(ColorIndex.xlColorIndexNone)
+    elif isinstance(color_or_rgb, int):
+        xl_range.interior_object.color.set(int_to_rgb(color_or_rgb))
+    else:
+        xl_range.interior_object.color.set(color_or_rgb)
+
+
+def get_color(xl_range):
+    if xl_range.interior_object.color_index.get() == kw.color_index_none:
+        return None
+    else:
+        return tuple(xl_range.interior_object.color.get())
\ No newline at end of file
