@@ -11,7 +11,8 @@ License: BSD 3-clause (see LICENSE.txt for details)
 """
 import sys
 import numbers
-from . import xlplatform, string_types, time_types
+import itertools
+from . import xlplatform, string_types, time_types, xrange
 from .constants import ChartType
 
 # Optional imports
@@ -33,17 +34,9 @@ class Workbook(object):
     * an unsaved workbook: ``wb = Workbook('Book1')``
     * a saved workbook (open or closed): ``wb = Workbook(r'C:\\path\\to\\file.xlsx')``
 
-    To create a connection when the Python function is called through the Excel VBA module, use:
+    To create a connection when the Python function is called from Excel, use:
 
-    ``wb = Workbook()``
-
-    When calling from VBA, always pack the ``Workbook`` call into the function being called from Excel, e.g.:
-
-    .. code-block:: python
-
-         def my_macro():
-            wb = Workbook()
-            Range('A1').value = 1
+    ``wb = Workbook.caller()``
     """
     def __init__(self, fullname=None, xl_workbook=None):
         if xl_workbook:
@@ -57,10 +50,6 @@ class Workbook(object):
             else:
                 # Open Excel and the Workbook
                 self.xl_app, self.xl_workbook = xlplatform.open_workbook(self.fullname)
-        elif len(sys.argv) > 2 and sys.argv[2] == 'from_xl':
-            # Connect to the workbook from which this code has been invoked
-            self.fullname = sys.argv[1].lower()
-            self.xl_app, self.xl_workbook = xlplatform.get_workbook(self.fullname)
         else:
             # Open Excel if necessary and create a new workbook
             self.xl_app, self.xl_workbook = xlplatform.new_workbook()
@@ -70,7 +59,32 @@ class Workbook(object):
 
         # Make the most recently created Workbook the default when creating Range objects directly
         xlplatform.set_xl_workbook_current(self.xl_workbook)
-        
+
+    @classmethod
+    def caller(cls):
+        """
+        Creates a connection when the Python function is called from Excel:
+
+        ``wb = Workbook.caller()``
+
+        When called from Excel, always pack the ``Workbook`` call into the function being called from Excel, e.g.:
+
+        .. code-block:: python
+
+             def my_macro():
+                wb = Workbook.caller()
+                Range('A1').value = 1
+        """
+        if len(sys.argv) > 2 and sys.argv[2] == 'from_xl':
+            # Connect to the workbook from which this code has been invoked
+            fullname = sys.argv[1].lower()
+            return cls(fullname)
+        elif xlplatform.get_xl_workbook_current():
+            # Called through ExcelPython connection
+            return cls(xl_workbook=xlplatform.get_xl_workbook_current())
+        else:
+            raise Exception('Workbook.caller() must not be called directly in Python but only through Excel.')
+
     @classmethod
     def current(cls):
         """
@@ -114,7 +128,7 @@ class Workbook(object):
     @staticmethod
     def get_xl_workbook(wkb):
         """
-        Returns the current xl_workbook if ``wkb`` is ``None``, otherwise the ``xl_workbook`` of ``wkb``. On Windows,
+        Returns the ``xl_workbook_current`` if ``wkb`` is ``None``, otherwise the ``xl_workbook`` of ``wkb``. On Windows,
         ``xl_workbook`` is a pywin32 COM object, on Mac it's an appscript object.
 
         Arguments
@@ -419,6 +433,19 @@ class Range(object):
 
         self.xl_range = xlplatform.get_range_from_indices(self.xl_sheet, self.row1, self.col1, self.row2, self.col2)
 
+        # Iterator object that returns cell coordinates: (1, 1), (1, 2) etc.
+        self.cell_iterator = itertools.product(xrange(self.row1, self.row2 + 1), xrange(self.col1, self.col2 + 1))
+
+    def __iter__(self):
+        return self
+
+    def __next__(self):
+        # StopIteration raised by itertools.product
+        return Range(xlplatform.get_worksheet_name(self.xl_sheet), next(self.cell_iterator), **self.kwargs)
+
+    # PY2 compatibility
+    next = __next__
+
     def is_cell(self):
         """
         Returns ``True`` if the Range consists of a single Cell otherwise ``False``.
@@ -455,6 +482,23 @@ class Range(object):
         else:
             return False
 
+    @property
+    def shape(self):
+        """
+        Tuple of Range dimensions.
+        """
+        return self.row2 - self.row1 + 1, self.col2 - self.col1 + 1
+
+    @property
+    def size(self):
+        """
+        Number of elements in the Range.
+        """
+        return self.shape[0] * self.shape[1]
+
+    def __len__(self):
+        return self.row2 - self.row1 + 1
+
     @property
     def value(self):
         """
@@ -826,6 +870,114 @@ class Range(object):
         return "<Range on Sheet '{0}' of Workbook '{1}'>".format(xlplatform.get_worksheet_name(self.xl_sheet),
                                                                  xlplatform.get_workbook_name(self.xl_workbook))
 
+    @property
+    def hyperlink(self):
+        """
+        Returns the hyperlink address of the specified Range (single Cell)
+
+        Examples
+        --------
+        >>> Range('A1').value
+        'www.xlwings.org'
+        >>> Range('A1').hyperlink
+        'http://www.xlwings.org'
+        """
+        return xlplatform.get_hyperlink_address(self.xl_range)
+
+    def add_hyperlink(self, address, text_to_display=None, screen_tip=None):
+        """
+        Adds a hyperlink to the specified Range (single Cell)
+        
+        Arguments
+        ---------
+        address : str
+            The address of the hyperlink.
+        text_to_display : str, default None
+            The text to be displayed for the hyperlink. Defaults to the hyperlink address.
+        screen_tip: str, default None
+            The screen tip to be displayed when the mouse pointer is paused over the hyperlink.
+            Default is set to '<address> - Click once to follow. Click and hold to select this cell.'
+        """
+        if text_to_display is None:
+            text_to_display = address
+        if address[:4] == 'www.':
+            address = 'http://' + address
+        if screen_tip is None:
+            screen_tip = address + ' - Click once to follow. Click and hold to select this cell.'
+        xlplatform.set_hyperlink(self.xl_range, address, text_to_display, screen_tip)
+
+    @property                 
+    def color(self):      
+        """
+        Gets and sets the background color of the specified Range.
+
+        To set the color, either use an RGB tuple ``(0, 0, 0)`` or a color constant.
+        To remove the background, set the color to ``None``, see Examples.
+
+        Returns
+        -------
+        RGB : tuple
+
+        Examples
+        --------
+        >>> Range('A1').color = (255,255,255)
+        >>> from xlwings import RgbColor
+        >>> Range('A2').color = RgbColor.rgbAqua
+        >>> Range('A2').color
+        (0, 255, 255)
+        >>> Range('A2').color = None
+        >>> Range('A2').color is None
+        True
+        """
+        return xlplatform.get_color(self.xl_range)
+
+    @color.setter
+    def color(self, color_or_rgb):
+        xlplatform.set_color(self.xl_range, color_or_rgb)
+
+    def resize(self, row_size=None, column_size=None):
+        """
+        Resizes the specified Range.
+
+        Returns
+        -------
+        Range : Range object
+        """
+        if row_size:
+            row2 = self.row1 + row_size - 1
+        else:
+            row2 = self.row1
+        if column_size:
+            col2 = self.col1 + column_size - 1
+        else:
+            col2 = self.col1
+
+        return Range(xlplatform.get_worksheet_name(self.xl_sheet), (self.row1, self.col1), (row2, col2), **self.kwargs)
+
+    def offset(self, row_offset=None, column_offset=None):
+        """
+        Returns a Range object that represents a Range that's offset from the specified range.
+
+        Returns
+        -------
+        Range : Range object
+        """
+
+        if row_offset:
+            row1 = self.row1 + row_offset
+            row2 = self.row2 + row_offset
+        else:
+            row1, row2 = self.row1, self.row2
+
+        if column_offset:
+            col1 = self.col1 + column_offset
+            col2 = self.col2 + column_offset
+        else:
+            col1, col2 = self.col1, self.col2
+
+        return Range(xlplatform.get_worksheet_name(self.xl_sheet), (row1, col1), (row2, col2), **self.kwargs)
+
+
 class Chart(object):
     """
     A Chart object that represents an existing Excel chart can be created with the following arguments::
