@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 # To run a single TestClass: nosetests -q -s test_xlwings:TestRange
+# To run a single Test: nosetests -q -s test_xlwings:TestRange.test_
 
 from __future__ import unicode_literals
 import os
@@ -7,7 +8,7 @@ import sys
 import nose
 from nose.tools import assert_equal
 from datetime import datetime
-from xlwings import Workbook, Sheet, Range, Chart, ChartType
+from xlwings import Workbook, Sheet, Range, Chart, ChartType, RgbColor
 if sys.platform.startswith('darwin'):
     from appscript import k as kw
 
@@ -604,6 +605,83 @@ class TestRange:
         res = Range((1,1),(3,3)).get_address(external=True)
         assert_equal(res, '[test_range_1.xlsx]Sheet1!$A$1:$C$3')
 
+    def test_hyperlink(self):
+        address = 'www.xlwings.org'
+        Range('A1').add_hyperlink(address)
+        assert_equal(Range('A1').value, address)
+        if sys.platform.startswith('darwin'):
+            assert_equal(Range('A1').hyperlink, 'http://' + address)
+        else:
+            assert_equal(Range('A1').hyperlink, 'http://' + address + '/')
+
+        Range('A2').add_hyperlink(address, 'test_link')
+        assert_equal(Range('A2').value, 'test_link')
+        if sys.platform.startswith('darwin'):
+            assert_equal(Range('A2').hyperlink, 'http://' + address)
+        else:
+            assert_equal(Range('A2').hyperlink, 'http://' + address + '/')
+
+    def test_color(self):
+        rgb = (30, 100, 200)
+
+        Range('A1').color = rgb
+        assert_equal(rgb, Range('A1').color)
+
+        Range('A2').color = RgbColor.rgbAqua
+        assert_equal((0, 255, 255), Range('A2').color)
+
+        Range('A2').color = None
+        assert_equal(Range('A2').color, None)
+
+        Range('A1:D4').color = rgb
+        assert_equal(rgb, Range('A1:D4').color)
+
+    def test_size(self):
+        assert_equal(Range('A1:C4').size, 12)
+
+    def test_shape(self):
+        assert_equal(Range('A1:C4').shape, (4, 3))
+
+    def test_len(self):
+        assert_equal(len(Range('A1:C4')), 4)
+
+    def test_iterator(self):
+        Range('A20').value = [[1., 2.], [3., 4.]]
+        l = []
+
+        for i in Range('A20:B21'):
+            l.append(i.value)
+
+        assert_equal(l, [1., 2., 3., 4.])
+
+        Range('Sheet2', 'A20').value = [[1., 2.], [3., 4.]]
+        l = []
+
+        for i in Range('Sheet2', 'A20:B21'):
+            l.append(i.value)
+
+        assert_equal(l, [1., 2., 3., 4.])
+
+    def test_resize(self):
+        r = Range('A1').resize(4, 5)
+        assert_equal(r.shape, (4, 5))
+
+        r = Range('A1').resize(row_size=4)
+        assert_equal(r.shape, (4, 1))
+
+        r = Range('A1:B4').resize(column_size=5)
+        assert_equal(r.shape, (1, 5))
+
+    def test_offset(self):
+        o = Range('A1:B3').offset(3, 4)
+        assert_equal(o.get_address(), '$E$4:$F$6')
+
+        o = Range('A1:B3').offset(row_offset=3)
+        assert_equal(o.get_address(), '$A$4:$B$6')
+
+        o = Range('A1:B3').offset(column_offset=4)
+        assert_equal(o.get_address(), '$E$1:$F$3')
+
 
 class TestChart:
     def setUp(self):
